@@ -270,6 +270,8 @@ types: list[str] = [
     "AWS::Elasticsearch::Domain",
     "AWS::Events::EventBus",
     "AWS::Events::Rule",
+    "AWS::FMS::NotificationChannel",
+    "AWS::FMS::Policy",
     "AWS::FSx::FileSystem",
     "AWS::FSx::Snapshot",
     "AWS::FSx::StorageVirtualMachine",
@@ -317,6 +319,8 @@ types: list[str] = [
     "AWS::IAM::User",
     "AWS::IAM::UserPolicy",
     "AWS::IAM::UserToGroupAddition",
+    "AWS::IdentityStore::Group",
+    "AWS::IdentityStore::GroupMembership",
     "AWS::ImageBuilder::Component",
     "AWS::ImageBuilder::ContainerRecipe",
     "AWS::ImageBuilder::DistributionConfiguration",
@@ -324,6 +328,7 @@ types: list[str] = [
     "AWS::ImageBuilder::ImagePipeline",
     "AWS::ImageBuilder::ImageRecipe",
     "AWS::ImageBuilder::InfrastructureConfiguration",
+    "AWS::ImageBuilder::LifecyclePolicy",
     "AWS::ImageBuilder::Workflow",
     "AWS::IoT::Certificate",
     "AWS::IoT::Policy",
@@ -561,7 +566,6 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
-    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -674,6 +678,7 @@ cached: list[str] = [
     "aws-ec2-networkinsightsanalysis.json",
     "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
+    "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
@@ -769,6 +774,8 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
+    "aws-fms-notificationchannel.json",
+    "aws-fms-policy.json",
     "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
@@ -810,6 +817,8 @@ cached: list[str] = [
     "aws-iam-user.json",
     "aws-iam-userpolicy.json",
     "aws-iam-usertogroupaddition.json",
+    "aws-identitystore-group.json",
+    "aws-identitystore-groupmembership.json",
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
@@ -817,6 +826,7 @@ cached: list[str] = [
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
+    "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
     "aws-iot-thingprincipalattachment.json",
     "aws-kafkaconnect-connector.json",
