@@ -114,6 +114,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::CapacityReservation",
     "AWS::Athena::DataCatalog",
@@ -158,6 +159,11 @@ types: list[str] = [
     "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
+    "AWS::BedrockAgentCore::BrowserCustom",
+    "AWS::BedrockAgentCore::CodeInterpreterCustom",
+    "AWS::BedrockAgentCore::Memory",
+    "AWS::BedrockAgentCore::Runtime",
+    "AWS::BedrockAgentCore::RuntimeEndpoint",
     "AWS::Budgets::Budget",
     "AWS::Budgets::BudgetsAction",
     "AWS::CDK::Metadata",
@@ -395,6 +401,8 @@ types: list[str] = [
     "AWS::EC2::LocalGatewayRouteTable",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
+    "AWS::EC2::LocalGatewayVirtualInterface",
+    "AWS::EC2::LocalGatewayVirtualInterfaceGroup",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
@@ -409,6 +417,11 @@ types: list[str] = [
     "AWS::EC2::PlacementGroup",
     "AWS::EC2::PrefixList",
     "AWS::EC2::Route",
+    "AWS::EC2::RouteServer",
+    "AWS::EC2::RouteServerAssociation",
+    "AWS::EC2::RouteServerEndpoint",
+    "AWS::EC2::RouteServerPeer",
+    "AWS::EC2::RouteServerPropagation",
     "AWS::EC2::RouteTable",
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
@@ -875,6 +888,7 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationCentralizationRule",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
     "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::OpenSearchServerless::AccessPolicy",
@@ -1345,6 +1359,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1430,6 +1445,11 @@ cached: list[str] = [
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
+    "aws-bedrockagentcore-browsercustom.json",
+    "aws-bedrockagentcore-codeinterpretercustom.json",
+    "aws-bedrockagentcore-memory.json",
+    "aws-bedrockagentcore-runtime.json",
+    "aws-bedrockagentcore-runtimeendpoint.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
@@ -1664,6 +1684,8 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetable.json",
     "aws-ec2-localgatewayroutetablevirtualinterfacegroupassociation.json",
     "aws-ec2-localgatewayroutetablevpcassociation.json",
+    "aws-ec2-localgatewayvirtualinterface.json",
+    "aws-ec2-localgatewayvirtualinterfacegroup.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
@@ -1678,6 +1700,11 @@ cached: list[str] = [
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
+    "aws-ec2-routeserver.json",
+    "aws-ec2-routeserverassociation.json",
+    "aws-ec2-routeserverendpoint.json",
+    "aws-ec2-routeserverpeer.json",
+    "aws-ec2-routeserverpropagation.json",
     "aws-ec2-routetable.json",
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
@@ -1999,6 +2026,7 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -2108,6 +2136,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-neptunegraph-graph.json",
     "aws-neptunegraph-privategraphendpoint.json",
     "aws-networkfirewall-firewall.json",
@@ -2127,6 +2156,7 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-observabilityadmin-organizationcentralizationrule.json",
     "aws-observabilityadmin-organizationtelemetryrule.json",
     "aws-observabilityadmin-telemetryrule.json",
     "aws-opensearchserverless-accesspolicy.json",
@@ -2262,10 +2292,13 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
