@@ -6,6 +6,11 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::ResourcePolicy",
+    "AWS::APS::RuleGroupsNamespace",
+    "AWS::APS::Scraper",
+    "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -72,6 +77,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -96,6 +102,9 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::Guardrail",
+    "AWS::Bedrock::GuardrailVersion",
     "AWS::CDK::Metadata",
     "AWS::CE::AnomalyMonitor",
     "AWS::CE::AnomalySubscription",
@@ -154,6 +163,7 @@ types: list[str] = [
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::CodePipeline::Webhook",
     "AWS::Cognito::IdentityPool",
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
@@ -230,11 +240,16 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
+    "AWS::EC2::NetworkInsightsAccessScope",
+    "AWS::EC2::NetworkInsightsAccessScopeAnalysis",
+    "AWS::EC2::NetworkInsightsAnalysis",
+    "AWS::EC2::NetworkInsightsPath",
     "AWS::EC2::NetworkInterface",
     "AWS::EC2::NetworkInterfaceAttachment",
     "AWS::EC2::NetworkInterfacePermission",
@@ -260,6 +275,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -317,6 +333,7 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
+    "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -340,6 +357,8 @@ types: list[str] = [
     "AWS::ElasticLoadBalancingV2::TrustStore",
     "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
     "AWS::Elasticsearch::Domain",
+    "AWS::Events::ApiDestination",
+    "AWS::Events::Connection",
     "AWS::Events::EventBus",
     "AWS::Events::EventBusPolicy",
     "AWS::Events::Rule",
@@ -382,7 +401,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -421,6 +442,9 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
+    "AWS::KafkaConnect::CustomPlugin",
+    "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -549,6 +573,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -605,9 +630,18 @@ types: list[str] = [
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
+    "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
+    "AWS::SMSVOICE::ConfigurationSet",
+    "AWS::SMSVOICE::OptOutList",
+    "AWS::SMSVOICE::PhoneNumber",
+    "AWS::SMSVOICE::Pool",
+    "AWS::SMSVOICE::ProtectConfiguration",
+    "AWS::SMSVOICE::ResourcePolicy",
+    "AWS::SMSVOICE::SenderId",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicInlinePolicy",
@@ -632,6 +666,7 @@ types: list[str] = [
     "AWS::SageMaker::Cluster",
     "AWS::SageMaker::MlflowTrackingServer",
     "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::Scheduler::Schedule",
     "AWS::Scheduler::ScheduleGroup",
     "AWS::SecretsManager::ResourcePolicy",
@@ -734,6 +769,7 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -744,7 +780,6 @@ cached: list[str] = [
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -782,6 +817,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appsync-api.json",
     "aws-appsync-apicache.json",
@@ -793,6 +829,10 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-resourcepolicy.json",
+    "aws-aps-rulegroupsnamespace.json",
+    "aws-aps-scraper.json",
+    "aws-aps-workspace.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -818,9 +858,13 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
+    "aws-bedrock-guardrail.json",
+    "aws-bedrock-guardrailversion.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
@@ -843,6 +887,7 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -869,7 +914,9 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
+    "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
@@ -941,11 +988,16 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinsightsaccessscope.json",
+    "aws-ec2-networkinsightsaccessscopeanalysis.json",
+    "aws-ec2-networkinsightsanalysis.json",
+    "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkperformancemetricsubscription.json",
@@ -965,9 +1017,12 @@ cached: list[str] = [
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
+    "aws-ec2-trafficmirrorsession.json",
+    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1025,6 +1080,7 @@ cached: list[str] = [
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
@@ -1043,6 +1099,9 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
+    "aws-emrserverless-application.json",
+    "aws-events-apidestination.json",
+    "aws-events-connection.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -1081,7 +1140,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -1101,6 +1162,7 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
+    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1110,8 +1172,12 @@ cached: list[str] = [
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kafkaconnect-connector.json",
+    "aws-kafkaconnect-customplugin.json",
+    "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
@@ -1126,8 +1192,6 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1192,21 +1256,15 @@ cached: list[str] = [
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
-    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
-    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
-    "aws-networkmanager-sitetositevpnattachment.json",
-    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
-    "aws-networkmanager-transitgatewayroutetableattachment.json",
-    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -1238,6 +1296,7 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
@@ -1273,10 +1332,13 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1289,11 +1351,14 @@ cached: list[str] = [
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
+    "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-cluster.json",
     "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-processingjob.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
@@ -1314,8 +1379,9 @@ cached: list[str] = [
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
-    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -1333,6 +1399,13 @@ cached: list[str] = [
     "aws-shield-proactiveengagement.json",
     "aws-shield-protection.json",
     "aws-shield-protectiongroup.json",
+    "aws-smsvoice-configurationset.json",
+    "aws-smsvoice-optoutlist.json",
+    "aws-smsvoice-phonenumber.json",
+    "aws-smsvoice-pool.json",
+    "aws-smsvoice-protectconfiguration.json",
+    "aws-smsvoice-resourcepolicy.json",
+    "aws-smsvoice-senderid.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
@@ -1372,10 +1445,8 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
-    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
-    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
