@@ -9,6 +9,9 @@ types: list[str] = [
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
+    "AWS::AmazonMQ::Broker",
+    "AWS::AmazonMQ::Configuration",
+    "AWS::AmazonMQ::ConfigurationAssociation",
     "AWS::ApiGateway::Account",
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
@@ -277,6 +280,7 @@ types: list[str] = [
     "AWS::ImageBuilder::ImagePipeline",
     "AWS::ImageBuilder::ImageRecipe",
     "AWS::ImageBuilder::InfrastructureConfiguration",
+    "AWS::ImageBuilder::LifecyclePolicy",
     "AWS::ImageBuilder::Workflow",
     "AWS::IoT::Certificate",
     "AWS::IoT::Policy",
@@ -386,7 +390,13 @@ types: list[str] = [
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::Insight",
+    "AWS::SecurityHub::ProductSubscription",
+    "AWS::SecurityHub::SecurityControl",
+    "AWS::SecurityHub::Standard",
     "AWS::ServiceDiscovery::HttpNamespace",
     "AWS::ServiceDiscovery::Instance",
     "AWS::ServiceDiscovery::PrivateDnsNamespace",
@@ -577,6 +587,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
     "aws-ec2-volume.json",
+    "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
@@ -665,6 +676,7 @@ cached: list[str] = [
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
+    "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
     "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
@@ -677,6 +689,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -749,7 +762,13 @@ cached: list[str] = [
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-automationrule.json",
+    "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-insight.json",
+    "aws-securityhub-productsubscription.json",
+    "aws-securityhub-securitycontrol.json",
+    "aws-securityhub-standard.json",
     "aws-servicediscovery-httpnamespace.json",
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
