@@ -76,6 +76,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -125,6 +126,9 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudTrail::Dashboard",
+    "AWS::CloudTrail::EventDataStore",
+    "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
     "AWS::CloudWatch::Alarm",
     "AWS::CloudWatch::AnomalyDetector",
@@ -385,6 +389,7 @@ types: list[str] = [
     "AWS::ImageBuilder::ImagePipeline",
     "AWS::ImageBuilder::ImageRecipe",
     "AWS::ImageBuilder::InfrastructureConfiguration",
+    "AWS::ImageBuilder::LifecyclePolicy",
     "AWS::ImageBuilder::Workflow",
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
@@ -545,6 +550,12 @@ types: list[str] = [
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
     "AWS::SSM::ResourceDataSync",
+    "AWS::SSO::Application",
+    "AWS::SSO::ApplicationAssignment",
+    "AWS::SSO::Assignment",
+    "AWS::SSO::Instance",
+    "AWS::SSO::InstanceAccessControlAttributeConfiguration",
+    "AWS::SSO::PermissionSet",
     "AWS::SageMaker::MlflowTrackingServer",
     "AWS::SageMaker::ModelCard",
     "AWS::SageMaker::ModelPackage",
@@ -654,6 +665,7 @@ cached: list[str] = [
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appsync-api.json",
     "aws-appsync-apicache.json",
@@ -669,7 +681,6 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
-    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -717,6 +728,9 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
+    "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
@@ -957,6 +971,7 @@ cached: list[str] = [
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
+    "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
@@ -1073,10 +1088,13 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
@@ -1133,6 +1151,12 @@ cached: list[str] = [
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
     "aws-ssm-resourcedatasync.json",
+    "aws-sso-application.json",
+    "aws-sso-applicationassignment.json",
+    "aws-sso-assignment.json",
+    "aws-sso-instance.json",
+    "aws-sso-instanceaccesscontrolattributeconfiguration.json",
+    "aws-sso-permissionset.json",
     "aws-stepfunctions-activity.json",
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
