@@ -146,6 +146,7 @@ types: list[str] = [
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::CodePipeline::Webhook",
     "AWS::Cognito::IdentityPool",
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
@@ -278,6 +279,7 @@ types: list[str] = [
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
+    "AWS::ECR::RepositoryCreationTemplate",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
@@ -728,6 +730,9 @@ types: list[str] = [
     "AWS::Transfer::User",
     "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
+    "AWS::VerifiedPermissions::Policy",
+    "AWS::VerifiedPermissions::PolicyStore",
+    "AWS::VerifiedPermissions::PolicyTemplate",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -779,7 +784,6 @@ cached: list[str] = [
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -797,6 +801,7 @@ cached: list[str] = [
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
     "aws-apigatewayv2-domainname.json",
+    "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
@@ -876,6 +881,7 @@ cached: list[str] = [
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
@@ -895,6 +901,7 @@ cached: list[str] = [
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
+    "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
@@ -956,7 +963,11 @@ cached: list[str] = [
     "aws-ec2-internetgateway.json",
     "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
+    "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
+    "aws-ec2-ipamresourcediscovery.json",
+    "aws-ec2-ipamresourcediscoveryassociation.json",
+    "aws-ec2-ipamscope.json",
     "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
@@ -964,6 +975,7 @@ cached: list[str] = [
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterface.json",
+    "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
@@ -975,7 +987,6 @@ cached: list[str] = [
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
-    "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
@@ -1016,9 +1027,9 @@ cached: list[str] = [
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
+    "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
-    "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
@@ -1034,6 +1045,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1090,6 +1102,7 @@ cached: list[str] = [
     "aws-gamelift-script.json",
     "aws-glue-classifier.json",
     "aws-glue-connection.json",
+    "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
     "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
@@ -1223,12 +1236,12 @@ cached: list[str] = [
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
     "aws-lakeformation-principalpermissions.json",
+    "aws-lakeformation-resource.json",
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1237,6 +1250,8 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
+    "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1259,6 +1274,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -1339,10 +1355,13 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
@@ -1371,6 +1390,7 @@ cached: list[str] = [
     "aws-sagemaker-notebookinstance.json",
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
@@ -1398,6 +1418,8 @@ cached: list[str] = [
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -1432,6 +1454,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
+    "aws-synthetics-canary.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
@@ -1440,6 +1463,9 @@ cached: list[str] = [
     "aws-transfer-user.json",
     "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
+    "aws-verifiedpermissions-policy.json",
+    "aws-verifiedpermissions-policystore.json",
+    "aws-verifiedpermissions-policytemplate.json",
     "aws-waf-bytematchset.json",
     "aws-waf-ipset.json",
     "aws-waf-rule.json",
