@@ -6,9 +6,11 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -112,6 +114,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -140,9 +143,12 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
     "AWS::Bedrock::ApplicationInferenceProfile",
+    "AWS::Bedrock::Blueprint",
+    "AWS::Bedrock::DataAutomationProject",
     "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
@@ -354,13 +360,26 @@ types: list[str] = [
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
     "AWS::DataZone::GroupProfile",
     "AWS::DataZone::Owner",
+    "AWS::DataZone::PolicyGrant",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
     "AWS::DataZone::ProjectProfile",
     "AWS::DataZone::SubscriptionTarget",
     "AWS::DataZone::UserProfile",
+    "AWS::Deadline::Farm",
+    "AWS::Deadline::Fleet",
+    "AWS::Deadline::LicenseEndpoint",
+    "AWS::Deadline::Limit",
+    "AWS::Deadline::MeteredProduct",
+    "AWS::Deadline::Monitor",
+    "AWS::Deadline::Queue",
+    "AWS::Deadline::QueueEnvironment",
+    "AWS::Deadline::QueueFleetAssociation",
+    "AWS::Deadline::QueueLimitAssociation",
+    "AWS::Deadline::StorageProfile",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
     "AWS::Detective::OrganizationAdmin",
@@ -404,12 +423,15 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::LocalGatewayRoute",
     "AWS::EC2::LocalGatewayRouteTable",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
+    "AWS::EC2::LocalGatewayVirtualInterface",
+    "AWS::EC2::LocalGatewayVirtualInterfaceGroup",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
@@ -447,6 +469,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -511,6 +534,7 @@ types: list[str] = [
     "AWS::EMR::WALWorkspace",
     "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
+    "AWS::EVS::Environment",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -620,7 +644,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::HealthLake::FHIRDatastore",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -653,6 +679,8 @@ types: list[str] = [
     "AWS::Inspector::AssessmentTemplate",
     "AWS::Inspector::ResourceGroup",
     "AWS::InspectorV2::CisScanConfiguration",
+    "AWS::InspectorV2::CodeSecurityIntegration",
+    "AWS::InspectorV2::CodeSecurityScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
     "AWS::Invoicing::InvoiceUnit",
@@ -666,6 +694,7 @@ types: list[str] = [
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
+    "AWS::IoT::EncryptionConfiguration",
     "AWS::IoT::FleetMetric",
     "AWS::IoT::JobTemplate",
     "AWS::IoT::Logging",
@@ -859,6 +888,9 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationCentralizationRule",
+    "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
+    "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::Omics::AnnotationStore",
     "AWS::Omics::ReferenceStore",
     "AWS::Omics::RunGroup",
@@ -945,6 +977,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -1019,8 +1052,10 @@ types: list[str] = [
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
+    "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1040,6 +1075,13 @@ types: list[str] = [
     "AWS::SES::ReceiptRuleSet",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
+    "AWS::SMSVOICE::ConfigurationSet",
+    "AWS::SMSVOICE::OptOutList",
+    "AWS::SMSVOICE::PhoneNumber",
+    "AWS::SMSVOICE::Pool",
+    "AWS::SMSVOICE::ProtectConfiguration",
+    "AWS::SMSVOICE::ResourcePolicy",
+    "AWS::SMSVOICE::SenderId",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicInlinePolicy",
@@ -1096,6 +1138,7 @@ types: list[str] = [
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
     "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
     "AWS::SageMaker::StudioLifecycleConfig",
@@ -1228,6 +1271,7 @@ types: list[str] = [
     "AWS::Wisdom::KnowledgeBase",
     "AWS::Wisdom::MessageTemplate",
     "AWS::Wisdom::MessageTemplateVersion",
+    "AWS::Wisdom::QuickResponse",
     "AWS::WorkSpaces::ConnectionAlias",
     "AWS::WorkSpaces::Workspace",
     "AWS::WorkSpaces::WorkspacesPool",
@@ -1238,6 +1282,7 @@ types: list[str] = [
     "AWS::WorkSpacesWeb::IpAccessSettings",
     "AWS::WorkSpacesWeb::NetworkSettings",
     "AWS::WorkSpacesWeb::Portal",
+    "AWS::WorkSpacesWeb::SessionLogger",
     "AWS::WorkSpacesWeb::TrustStore",
     "AWS::WorkSpacesWeb::UserAccessLoggingSettings",
     "AWS::WorkSpacesWeb::UserSettings",
@@ -1263,6 +1308,7 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-amplify-app.json",
     "aws-amplify-branch.json",
     "aws-amplify-domain.json",
@@ -1279,7 +1325,6 @@ cached: list[str] = [
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -1323,6 +1368,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1358,9 +1404,11 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -1389,10 +1437,12 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-bcmdataexports-export.json",
-    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
+    "aws-bedrock-blueprint.json",
+    "aws-bedrock-dataautomationproject.json",
     "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
@@ -1411,6 +1461,7 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cleanrooms-analysistemplate.json",
@@ -1584,8 +1635,10 @@ cached: list[str] = [
     "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
+    "aws-datazone-formtype.json",
     "aws-datazone-groupprofile.json",
     "aws-datazone-owner.json",
+    "aws-datazone-policygrant.json",
     "aws-datazone-project.json",
     "aws-datazone-projectmembership.json",
     "aws-datazone-projectprofile.json",
@@ -1594,6 +1647,17 @@ cached: list[str] = [
     "aws-dax-cluster.json",
     "aws-dax-parametergroup.json",
     "aws-dax-subnetgroup.json",
+    "aws-deadline-farm.json",
+    "aws-deadline-fleet.json",
+    "aws-deadline-licenseendpoint.json",
+    "aws-deadline-limit.json",
+    "aws-deadline-meteredproduct.json",
+    "aws-deadline-monitor.json",
+    "aws-deadline-queue.json",
+    "aws-deadline-queueenvironment.json",
+    "aws-deadline-queuefleetassociation.json",
+    "aws-deadline-queuelimitassociation.json",
+    "aws-deadline-storageprofile.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
     "aws-detective-organizationadmin.json",
@@ -1649,12 +1713,15 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-localgatewayroute.json",
     "aws-ec2-localgatewayroutetable.json",
     "aws-ec2-localgatewayroutetablevirtualinterfacegroupassociation.json",
     "aws-ec2-localgatewayroutetablevpcassociation.json",
+    "aws-ec2-localgatewayvirtualinterface.json",
+    "aws-ec2-localgatewayvirtualinterfacegroup.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
@@ -1688,9 +1755,11 @@ cached: list[str] = [
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrorsession.json",
+    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1793,6 +1862,7 @@ cached: list[str] = [
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
     "aws-eventschemas-schema.json",
+    "aws-evs-environment.json",
     "aws-fis-experimenttemplate.json",
     "aws-fis-targetaccountconfiguration.json",
     "aws-fms-notificationchannel.json",
@@ -1831,7 +1901,6 @@ cached: list[str] = [
     "aws-glue-schemaversionmetadata.json",
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
-    "aws-glue-tableoptimizer.json",
     "aws-glue-trigger.json",
     "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
@@ -1861,7 +1930,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-healthlake-fhirdatastore.json",
     "aws-iam-accesskey.json",
     "aws-iam-group.json",
@@ -1884,6 +1955,7 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
+    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1893,6 +1965,8 @@ cached: list[str] = [
     "aws-inspector-assessmenttemplate.json",
     "aws-inspector-resourcegroup.json",
     "aws-inspectorv2-cisscanconfiguration.json",
+    "aws-inspectorv2-codesecurityintegration.json",
+    "aws-inspectorv2-codesecurityscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-invoicing-invoiceunit.json",
@@ -1906,6 +1980,7 @@ cached: list[str] = [
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
+    "aws-iot-encryptionconfiguration.json",
     "aws-iot-fleetmetric.json",
     "aws-iot-jobtemplate.json",
     "aws-iot-logging.json",
@@ -2053,6 +2128,7 @@ cached: list[str] = [
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediastore-container.json",
     "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
     "aws-memorydb-multiregioncluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
@@ -2075,26 +2151,24 @@ cached: list[str] = [
     "aws-neptunegraph-privategraphendpoint.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
-    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
-    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
-    "aws-networkmanager-sitetositevpnattachment.json",
-    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
-    "aws-networkmanager-transitgatewayroutetableattachment.json",
-    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-observabilityadmin-organizationcentralizationrule.json",
+    "aws-observabilityadmin-organizationtelemetryrule.json",
+    "aws-observabilityadmin-telemetryrule.json",
     "aws-omics-annotationstore.json",
     "aws-omics-referencestore.json",
     "aws-omics-rungroup.json",
@@ -2131,7 +2205,6 @@ cached: list[str] = [
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
-    "aws-pcs-cluster.json",
     "aws-pcs-computenodegroup.json",
     "aws-pcs-queue.json",
     "aws-pinpoint-apnschannel.json",
@@ -2179,6 +2252,7 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
@@ -2227,10 +2301,13 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -2249,8 +2326,10 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
+    "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-cluster.json",
@@ -2276,6 +2355,7 @@ cached: list[str] = [
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
     "aws-sagemaker-partnerapp.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
@@ -2313,10 +2393,8 @@ cached: list[str] = [
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolio.json",
-    "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
-    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -2355,6 +2433,13 @@ cached: list[str] = [
     "aws-shield-protectiongroup.json",
     "aws-signer-profilepermission.json",
     "aws-signer-signingprofile.json",
+    "aws-smsvoice-configurationset.json",
+    "aws-smsvoice-optoutlist.json",
+    "aws-smsvoice-phonenumber.json",
+    "aws-smsvoice-pool.json",
+    "aws-smsvoice-protectconfiguration.json",
+    "aws-smsvoice-resourcepolicy.json",
+    "aws-smsvoice-senderid.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
@@ -2409,12 +2494,9 @@ cached: list[str] = [
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
     "aws-voiceid-domain.json",
-    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
-    "aws-vpclattice-resourcegateway.json",
-    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
@@ -2457,6 +2539,7 @@ cached: list[str] = [
     "aws-wisdom-knowledgebase.json",
     "aws-wisdom-messagetemplate.json",
     "aws-wisdom-messagetemplateversion.json",
+    "aws-wisdom-quickresponse.json",
     "aws-workspaces-connectionalias.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
@@ -2470,6 +2553,7 @@ cached: list[str] = [
     "aws-workspacesweb-ipaccesssettings.json",
     "aws-workspacesweb-networksettings.json",
     "aws-workspacesweb-portal.json",
+    "aws-workspacesweb-sessionlogger.json",
     "aws-workspacesweb-truststore.json",
     "aws-workspacesweb-useraccessloggingsettings.json",
     "aws-workspacesweb-usersettings.json",
